@@ -11,7 +11,7 @@
 int main (void)
 {
 	KeySet * myConfig = ksNew (0, KS_END);
-	Key * parentKey = keyNew ("/sw/MyApp", KEY_CASCADING_NAME, KEY_END);
+	Key * parentKey = keyNew ("/sw/MyApp", KEY_END);
 	KDB * handle = kdbOpen (parentKey);
 
 	kdbGet (handle, myConfig, parentKey); // kdbGet() must be first
