@@ -164,7 +164,7 @@ inline void KDB::close (Key & errorKey) throw ()
  */
 inline int KDB::get (KeySet & returned, std::string const & keyname)
 {
-	Key parentKey (keyname.c_str (), KEY_CASCADING_NAME, KEY_END);
+	Key parentKey (keyname.c_str (), KEY_END);
 	return get (returned, parentKey);
 }
 
@@ -206,7 +206,7 @@ inline int KDB::get (KeySet & returned, Key & parentKey)
  */
 inline int KDB::set (KeySet & returned, std::string const & keyname)
 {
-	Key parentKey (keyname.c_str (), KEY_CASCADING_NAME, KEY_END);
+	Key parentKey (keyname.c_str (), KEY_END);
 	return set (returned, parentKey);
 }
 
