@@ -25,22 +25,12 @@ typedef enum {
 	GELEKTRA_KEY_END            = KEY_END,
 	GELEKTRA_KEY_NAME           = KEY_NAME,
 	GELEKTRA_KEY_VALUE          = KEY_VALUE,
-	GELEKTRA_KEY_OWNER          = KEY_OWNER,
 	GELEKTRA_KEY_COMMENT        = KEY_COMMENT,
 	GELEKTRA_KEY_BINARY         = KEY_BINARY,
-	GELEKTRA_KEY_UID            = KEY_UID,
-	GELEKTRA_KEY_GID            = KEY_GID,
-	GELEKTRA_KEY_MODE           = KEY_MODE,
-	GELEKTRA_KEY_ATIME          = KEY_ATIME,
-	GELEKTRA_KEY_MTIME          = KEY_MTIME,
-	GELEKTRA_KEY_CTIME          = KEY_CTIME,
 	GELEKTRA_KEY_SIZE           = KEY_SIZE,
 	GELEKTRA_KEY_FUNC           = KEY_FUNC,
-	GELEKTRA_KEY_DIR            = KEY_DIR,
 	GELEKTRA_KEY_META           = KEY_META,
-	GELEKTRA_KEY_NULL           = KEY_NULL,
-	GELEKTRA_KEY_CASCADING_NAME = KEY_CASCADING_NAME,
-	GELEKTRA_KEY_META_NAME      = KEY_META_NAME
+	GELEKTRA_KEY_NULL           = KEY_NULL
 } GElektraKeySwitch;
 // clang-format on
 
@@ -96,7 +86,6 @@ gssize gelektra_key_addbasename (GElektraKey * key, const char * basename);
 
 gssize gelektra_key_getnamesize (const GElektraKey * key);
 gssize gelektra_key_getbasenamesize (const GElektraKey * key);
-gssize gelektra_key_getfullnamesize (const GElektraKey * key);
 
 /* value operations */
 gssize gelektra_key_setstring (GElektraKey * key, const gchar * value);
@@ -130,7 +119,6 @@ gboolean gelektra_key_issystem (const GElektraKey * key);
 gboolean gelektra_key_isuser (const GElektraKey * key);
 gboolean gelektra_key_isstring (const GElektraKey * key);
 gboolean gelektra_key_isbinary (const GElektraKey * key);
-gboolean gelektra_key_isinactive (const GElektraKey * key);
 gboolean gelektra_key_isbelow (const GElektraKey * key, const GElektraKey * other);
 gboolean gelektra_key_isbeloworsame (const GElektraKey * key, const GElektraKey * other);
 gboolean gelektra_key_isdirectbelow (const GElektraKey * key, const GElektraKey * other);
