@@ -16,8 +16,8 @@
 #error "no gsetting priority selected"
 #endif
 
-#define G_ELEKTRA_SETTINGS_SYSTEM "system"
-#define G_ELEKTRA_SETTINGS_USER "user"
+#define G_ELEKTRA_SETTINGS_SYSTEM "system:/"
+#define G_ELEKTRA_SETTINGS_USER "user:/"
 #ifndef G_ELEKTRA_SETTINGS_PATH
 #define G_ELEKTRA_SETTINGS_PATH "/sw"
 #endif
@@ -513,7 +513,7 @@ static void elektra_settings_backend_sync (GSettingsBackend * backend)
 static void elektra_settings_backend_init (ElektraSettingsBackend * esb)
 {
 	g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, "%s.", "Init new ElektraSettingsBackend");
-	esb->gkey = gelektra_key_new ("", KEY_CASCADING_NAME, KEY_END);
+	esb->gkey = gelektra_key_new ("", KEY_END);
 	esb->gkdb = gelektra_kdb_open (esb->gkey);
 	esb->gks = gelektra_keyset_new (0, GELEKTRA_KEYSET_END);
 	esb->subscription_gks = gelektra_keyset_new (0, GELEKTRA_KEYSET_END);
