@@ -8,11 +8,11 @@
 //! ```
 //! # use elektra::{KeyBuilder,StringKey,WriteableKey,ReadableKey};
 //! # fn main() -> Result<(), Box<dyn std::error::Error>> {
-//! let mut key = StringKey::new("user/test/language")?;
+//! let mut key = StringKey::new("user:/test/language")?;
 //! key.set_value("rust");
 //!
 //! assert_eq!(key.value(), "rust");
-//! assert_eq!(key.name(), "user/test/language");
+//! assert_eq!(key.name(), "user:/test/language");
 //!
 //! # Ok(())
 //! # }
@@ -22,7 +22,7 @@
 //! ```
 //! # use elektra::{KeyBuilder,StringKey,WriteableKey,ReadableKey};
 //! # fn main() -> Result<(), Box<dyn std::error::Error>> {
-//! let mut key = StringKey::new("user/test/meta")?;
+//! let mut key = StringKey::new("user:/test/meta")?;
 //! key.set_meta("rust", "😃");
 //!
 //! assert_eq!(key.meta("rust")?.value(), "😃");
@@ -413,14 +413,14 @@ mod tests {
 
     #[test]
     fn can_write_read_key() {
-        let key_name = "user/test/key";
+        let key_name = "user:/test/key";
         let key = StringKey::new(key_name).unwrap();
         assert_eq!(key.name(), key_name);
     }
 
     #[test]
     fn can_write_read_key_value() {
-        let key_name = "user/test/key";
+        let key_name = "user:/test/key";
         let utf8_value = "😃";
         let mut key: StringKey = StringKey::new(key_name).unwrap();
         key.set_string(utf8_value);
@@ -430,7 +430,7 @@ mod tests {
 
     #[test]
     fn can_duplicate_key() {
-        let key_name = "user/test/key";
+        let key_name = "user:/test/key";
         let key_dup;
         {
             let key = StringKey::new(key_name).unwrap();
@@ -442,7 +442,7 @@ mod tests {
 
     #[test]
     fn can_write_read_binary() {
-        let mut key = BinaryKey::new("user/test/rust").unwrap();
+        let mut key = BinaryKey::new("user:/test/rust").unwrap();
         let binary_content: [u8; 7] = [25, 34, 0, 254, 1, 0, 7];
         key.set_binary(&binary_content);
         let read_content = key.binary();
@@ -450,7 +450,7 @@ mod tests {
     }
     #[test]
     fn can_write_read_empty_binary() {
-        let mut key = BinaryKey::new("user/test/binary").unwrap();
+        let mut key = BinaryKey::new("user:/test/binary").unwrap();
         let binary_content: [u8; 0] = [];
         key.set_binary(&binary_content);
         let vec = key.binary();
@@ -460,8 +460,8 @@ mod tests {
     #[allow(clippy::eq_op)]
     #[test]
     fn equality_is_exclusive() {
-        let key = BinaryKey::new("user/test/exclusive").unwrap();
-        let key2 = BinaryKey::new("dir/test/exclusive").unwrap();
+        let key = BinaryKey::new("user:/test/exclusive").unwrap();
+        let key2 = BinaryKey::new("dir:/test/exclusive").unwrap();
         assert!(!(key != key));
         assert!(key == key);
 
@@ -472,14 +472,14 @@ mod tests {
     #[allow(clippy::eq_op)]
     #[test]
     fn equality_is_reflexive() {
-        let key = StringKey::new("user/test/reflexive").unwrap();
+        let key = StringKey::new("user:/test/reflexive").unwrap();
         assert!(key == key);
     }
 
     #[test]
     fn equality_is_symmetric() {
-        let key = BinaryKey::new("user/test/symmetric").unwrap();
-        let key_dup = BinaryKey::new("user/test/symmetric").unwrap();
+        let key = BinaryKey::new("user:/test/symmetric").unwrap();
+        let key_dup = BinaryKey::new("user:/test/symmetric").unwrap();
 
         assert!(key_dup == key);
         assert!(key == key_dup);
@@ -487,9 +487,9 @@ mod tests {
 
     #[test]
     fn equality_is_transitive() {
-        let key = BinaryKey::new("user/test/transitive").unwrap();
-        let key2 = BinaryKey::new("user/test/transitive").unwrap();
-        let key3 = BinaryKey::new("user/test/transitive").unwrap();
+        let key = BinaryKey::new("user:/test/transitive").unwrap();
+        let key2 = BinaryKey::new("user:/test/transitive").unwrap();
+        let key3 = BinaryKey::new("user:/test/transitive").unwrap();
 
         assert!(key == key2);
         assert!(key2 == key3);
@@ -498,9 +498,9 @@ mod tests {
 
     #[test]
     fn keys_are_ordered() {
-        let key = BinaryKey::new("user/test/a").unwrap();
-        let key2 = BinaryKey::new("user/test/b").unwrap();
-        let key3 = BinaryKey::new("user/test/c").unwrap();
+        let key = BinaryKey::new("user:/test/a").unwrap();
+        let key2 = BinaryKey::new("user:/test/b").unwrap();
+        let key3 = BinaryKey::new("user:/test/c").unwrap();
 
         assert!(key != key2);
         assert!(key < key2);
@@ -516,8 +516,8 @@ mod tests {
 
     #[test]
     fn keys_are_ordered_with_metadata() -> Result<(), KeyNameInvalidError> {
-        let k1: StringKey = KeyBuilder::new("user/a")?.meta("owner", "abc")?.build();
-        let k2: StringKey = KeyBuilder::new("user/a")?.meta("owner", "abz")?.build();
+        let k1: StringKey = KeyBuilder::new("user:/a")?.meta("owner", "abc")?.build();
+        let k2: StringKey = KeyBuilder::new("user:/a")?.meta("owner", "abz")?.build();
         assert!(k1 < k2);
         assert!(k2 > k1);
         Ok(())
@@ -525,7 +525,7 @@ mod tests {
 
     #[test]
     fn can_reference_count() {
-        let mut key = BinaryKey::new("user/test/a").unwrap();
+        let mut key = BinaryKey::new("user:/test/a").unwrap();
         assert_eq!(key.get_ref(), 0);
         unsafe { key.inc_ref() };
         assert_eq!(key.get_ref(), 1);
@@ -535,7 +535,7 @@ mod tests {
 
     #[test]
     fn error_on_missing_metaname() {
-        let key = StringKey::new("user/test/metatest").unwrap();
+        let key = StringKey::new("user:/test/metatest").unwrap();
         assert!(key.meta("nonexistent metaname").is_err());
     }
     #[test]
@@ -549,7 +549,7 @@ mod tests {
     #[test]
     fn can_iterate_key() {
         let mut key = StringKey::new_empty();
-        let meta = [("meta1", "val1"), ("meta2", "val2")];
+        let meta = [("meta:/meta1", "val1"), ("meta:/meta2", "val2")];
         key.set_meta(meta[0].0, meta[0].1).unwrap();
         key.set_meta(meta[1].0, meta[1].1).unwrap();
 
@@ -577,38 +577,27 @@ mod tests {
 
     #[test]
     fn can_cast_key_types() {
-        let key = StringKey::new("user/test/cast").unwrap();
+        let key = StringKey::new("user:/test/cast").unwrap();
         let mut bin_key = BinaryKey::from(key);
         let val = b"data";
         bin_key.set_value(val);
         assert_eq!(bin_key.value(), val);
     }
 
-    #[test]
-    fn can_get_fullname() -> Result<(), KeyNameInvalidError> {
-        let name = "user/test/fulltest";
-        let key: StringKey = KeyBuilder::new(name)?
-            .meta("metaname", "metavalue")?
-            .meta("owner", "me")?
-            .build();
-        assert_eq!(key.fullname(), "user:me/test/fulltest");
-        Ok(())
-    }
-
     #[test]
     fn can_iterate_name() -> Result<(), KeyNameInvalidError> {
-        let names = ["user", "test", "fulltest"];
+        let names = ["user:", "test", "fulltest"];
         let key = StringKey::new(&names.join("/"))?;
         let mut did_iterate = false;
-        for (i, name) in key.name_iter().enumerate() {
+        for (i, name) in key.name_iter().enumerate().skip(1) {
             did_iterate = true;
             assert_eq!(name, names[i]);
         }
         assert!(did_iterate);
 
-        let nameless_key = StringKey::new_empty();
-        let mut iter = nameless_key.name_iter();
-        assert_eq!(iter.next(), None);
+        let root_key = StringKey::new_empty();
+        let mut iter = root_key.name_iter();
+        assert_eq!(iter.next().unwrap(), "\u{1}"); // TODO: use KEY_NS_CASCADING instead of hardcoded value
 
         Ok(())
     }
