@@ -6,6 +6,8 @@
  * @copyright BSD License (see LICENSE.md or https://www.libelektra.org)
  */
 
+#include "kdbprivate.h"
+#include <kdb.h>
 #ifdef HAVE_KDBCONFIG_H
 #include "kdbconfig.h"
 #endif
@@ -249,7 +251,6 @@ KeySet * ksVNew (size_t alloc, va_list va)
 	keyset = (KeySet *) elektraMalloc (sizeof (KeySet));
 	if (!keyset)
 	{
-		/*errno = KDB_ERR_NOMEM;*/
 		return 0;
 	}
 
@@ -266,7 +267,6 @@ KeySet * ksVNew (size_t alloc, va_list va)
 	keyset->array = elektraMalloc (sizeof (struct _Key *) * keyset->alloc);
 	if (!keyset->array)
 	{
-		/*errno = KDB_ERR_NOMEM;*/
 		return 0;
 	}
 	keyset->array[0] = 0;
@@ -483,7 +483,6 @@ int ksClear (KeySet * ks)
 
 	if ((ks->array = elektraMalloc (sizeof (struct _Key *) * KEYSET_SIZE)) == 0)
 	{
-		/*errno = KDB_ERR_NOMEM;*/
 		ks->size = 0;
 		return -1;
 	}
@@ -506,37 +505,17 @@ int ksClear (KeySet * ks)
  */
 static int keyCompareByName (const void * p1, const void * p2)
 {
-	Key * key1 = *(Key **) p1;
-	Key * key2 = *(Key **) p2;
-	const void * name1 = key1->key + key1->keySize;
-	const void * name2 = key2->key + key2->keySize;
-	size_t const nameSize1 = key1->keyUSize;
-	size_t const nameSize2 = key2->keyUSize;
-	int ret = 0;
-	if (nameSize1 == nameSize2)
+	Key * k1 = *(Key **) p1;
+	Key * k2 = *(Key **) p2;
+
+	int k1Shorter = k1->keyUSize < k2->keyUSize;
+	size_t size = k1Shorter ? k1->keyUSize : k2->keyUSize;
+	int cmp = memcmp (k1->ukey, k2->ukey, size);
+	if (cmp != 0 || k1->keyUSize == k2->keyUSize)
 	{
-		ret = memcmp (name1, name2, nameSize2);
+		return cmp;
 	}
-	else
-	{
-		if (nameSize1 < nameSize2)
-		{
-			ret = memcmp (name1, name2, nameSize1);
-			if (ret == 0)
-			{
-				ret = -1;
-			}
-		}
-		else
-		{
-			ret = memcmp (name1, name2, nameSize2);
-			if (ret == 0)
-			{
-				ret = 1;
-			}
-		}
-	}
-	return ret;
+	return k1Shorter ? -1 : 1;
 }
 
 /**
@@ -578,7 +557,6 @@ static int keyCompareByNameOwner (const void * p1, const void * p2)
 	return ret;
 }
 
-
 /**
  * Compare the name of two keys.
  *
@@ -616,21 +594,13 @@ static int keyCompareByNameOwner (const void * p1, const void * p2)
  *
  * Here are some more examples:
  * @code
-Key *k1 = keyNew("user/a", KEY_END);
-Key *k2 = keyNew("user/b", KEY_END);
+Key *k1 = keyNew("user:/a", KEY_END);
+Key *k2 = keyNew("user:/b", KEY_END);
 
 // keyCmp(k1,k2) < 0
 // keyCmp(k2,k1) > 0
  * @endcode
  *
- * And even more:
- * @code
-Key *k1 = keyNew("user/a", KEY_OWNER, "markus", KEY_END);
-Key *k2 = keyNew("user/a", KEY_OWNER, "max", KEY_END);
-
-// keyCmp(k1,k2) < 0
-// keyCmp(k2,k1) > 0
- * @endcode
  *
  * Do not strcmp the keyName() yourself because
  * the result differs from simple ascii comparison.
@@ -1096,26 +1066,26 @@ static int elektraKsFindCutpoint (KeySet * ks, const Key * cutpoint, size_t * fr
  * @par Example:
  *
  * You have the keyset @p ks:
- * - @p system/mountpoint/interest
- * - @p system/mountpoint/interest/folder
- * - @p system/mountpoint/interest/folder/key1
- * - @p system/mountpoint/interest/folder/key2
- * - @p system/mountpoint/other/key1
+ * - @p system:/mountpoint/interest
+ * - @p system:/mountpoint/interest/folder
+ * - @p system:/mountpoint/interest/folder/key1
+ * - @p system:/mountpoint/interest/folder/key2
+ * - @p system:/mountpoint/other/key1
  *
  * When you use
  * @snippet ksCut.c cut
  *
  * Then in @p returned are:
- * - @p system/mountpoint/interest
- * - @p system/mountpoint/interest/folder
- * - @p system/mountpoint/interest/folder/key1
- * - @p system/mountpoint/interest/folder/key2
+ * - @p system:/mountpoint/interest
+ * - @p system:/mountpoint/interest/folder
+ * - @p system:/mountpoint/interest/folder/key1
+ * - @p system:/mountpoint/interest/folder/key2
  *
  * And in @p ks are:
- * - @p system/mountpoint/other/key1
+ * - @p system:/mountpoint/other/key1
  *
  * So kdbSet() permanently removes all keys below
- * @p system/mountpoint/interest.
+ * @p system:/mountpoint/interest.
  *
  * @see kdbGet() for explanation why you might get more keys than you
  * requested.
@@ -1146,85 +1116,46 @@ KeySet * ksCut (KeySet * ks, const Key * cutpoint)
 
 	char * name = cutpoint->key;
 	if (!name) return 0;
-	// if (strcmp(name, "")) return 0;
+	if (strcmp (name, "") == 0) return 0;
 
 	elektraOpmphmInvalidate (ks);
 
-	if (name[0] == '/')
+	if (cutpoint->ukey[0] == KEY_NS_CASCADING)
 	{
-		Key * key = (Key *) cutpoint;
-		size_t size = key->keySize;
-		size_t usize = key->keyUSize;
-		size_t length = strlen (name) + ELEKTRA_MAX_NAMESPACE_SIZE;
-		char newname[length * 2];
-
 		ret = ksNew (0, KS_END);
 
+		// HACK: ksCut does not use escaped name (key->key), so we don't need to change it
 		for (elektraNamespace ns = KEY_NS_FIRST; ns <= KEY_NS_LAST; ++ns)
 		{
 			int validNS = 1;
 			switch (ns)
 			{
 			case KEY_NS_SPEC:
-				strncpy (newname + 2, "spec", 5);
-				strcpy (newname + 6, name);
-				key->key = newname + 2;
-				key->keySize = length - 2;
-				if (!strcmp (name, "/")) key->keySize = 5;
-				elektraFinalizeName (key);
-				break;
 			case KEY_NS_PROC:
-				strncpy (newname + 2, "proc", 5);
-				strcpy (newname + 6, name);
-				key->key = newname + 2;
-				key->keySize = length - 2;
-				if (!strcmp (name, "/")) key->keySize = 5;
-				elektraFinalizeName (key);
-				break;
 			case KEY_NS_DIR:
-				strncpy (newname + 3, "dir", 4);
-				strcpy (newname + 6, name);
-				key->key = newname + 3;
-				key->keySize = length - 3;
-				if (!strcmp (name, "/")) key->keySize = 4;
-				elektraFinalizeName (key);
-				break;
 			case KEY_NS_USER:
-				strncpy (newname + 2, "user", 5);
-				strcpy (newname + 6, name);
-				key->key = newname + 2;
-				key->keySize = length - 2;
-				if (!strcmp (name, "/")) key->keySize = 5;
-				elektraFinalizeName (key);
-				break;
 			case KEY_NS_SYSTEM:
-				strncpy (newname, "system", 7);
-				strcpy (newname + 6, name);
-				key->key = newname;
-				key->keySize = length;
-				if (!strcmp (name, "/")) key->keySize = 7;
-				elektraFinalizeName (key);
-				break;
-			case KEY_NS_EMPTY:
-			case KEY_NS_NONE:
 			case KEY_NS_META:
+				((Key *) cutpoint)->ukey[0] = ns;
+				break;
+			case KEY_NS_NONE:
 			case KEY_NS_CASCADING:
+			case KEY_NS_DEFAULT:
 				validNS = 0;
 			}
 			if (validNS)
 			{
-				KeySet * n = ksCut (ks, key);
+				KeySet * n = ksCut (ks, cutpoint);
 				ksAppend (ret, n);
 				ksDel (n);
 			}
 		}
 
 		// restore old cascading name
-		key->key = name;
-		key->keySize = size;
-		key->keyUSize = usize;
+		((Key *) cutpoint)->ukey[0] = KEY_NS_CASCADING;
 
 		// now look for cascading keys
+		// TODO: cascading keys shouldn't be allowed in KeySet anymore
 	}
 
 	set_cursor = elektraKsFindCutpoint (ks, cutpoint, &it, &found);
@@ -1268,7 +1199,7 @@ KeySet * ksCut (KeySet * ks, const Key * cutpoint)
 ks1=ksNew(0, KS_END);
 ks2=ksNew(0, KS_END);
 
-k1=keyNew("user/name", KEY_END); // ref counter 0
+k1=keyNew("user:/name", KEY_END); // ref counter 0
 ksAppendKey(ks1, k1); // ref counter 1
 ksAppendKey(ks2, k1); // ref counter 2
 
@@ -1470,7 +1401,7 @@ Key * ksTail (const KeySet * ks)
  * in a keyset:
  *
  * @code
-cursor_t jump;
+elektraCursor jump;
 ksRewind (ks);
 while ((key = keyNextMeta (ks))!=0)
 {
@@ -1495,7 +1426,7 @@ while ((key = keyNextMeta (ks))!=0)
  * @code
 int f (KeySet *ks)
 {
-	cursor_t state = ksGetCursor(ks);
+	elektraCursor state = ksGetCursor(ks);
 
 	// work with keyset
 
@@ -1535,14 +1466,14 @@ int f (KeySet *ks)
  * @return an invalid cursor on NULL pointer or after ksRewind()
  * @see ksNext(), ksSetCursor()
  */
-cursor_t ksGetCursor (const KeySet * ks)
+elektraCursor ksGetCursor (const KeySet * ks)
 {
-	if (!ks) return (cursor_t) -1;
+	if (!ks) return (elektraCursor) -1;
 
 	if (ks->cursor == 0)
-		return (cursor_t) -1;
+		return (elektraCursor) -1;
 	else
-		return (cursor_t) ks->current;
+		return (elektraCursor) ks->current;
 }
 
 /**
@@ -1556,11 +1487,11 @@ cursor_t ksGetCursor (const KeySet * ks)
  * @retval NULL on NULL pointer, negative cursor position
  * or a position that does not lie within the keyset
  */
-Key * ksAtCursor (KeySet * ks, cursor_t pos)
+Key * ksAtCursor (KeySet * ks, elektraCursor pos)
 {
 	if (!ks) return 0;
 	if (pos < 0) return 0;
-	if (ks->size < (size_t) pos) return 0;
+	if (ks->size <= (size_t) pos) return 0;
 	return ks->array[pos];
 }
 
@@ -1576,7 +1507,7 @@ Key * ksAtCursor (KeySet * ks, cursor_t pos)
  * with KDB_O_POP.
  *
  * @code
-cursor_t cursor;
+elektraCursor cursor;
 ..
 // key now in any position here
 cursor = ksGetCursor (ks);
@@ -1596,11 +1527,11 @@ ksCurrent(ks); // in same position as before
  * @retval -1 on NULL pointer
  * @see ksNext(), ksGetCursor()
  */
-int ksSetCursor (KeySet * ks, cursor_t cursor)
+int ksSetCursor (KeySet * ks, elektraCursor cursor)
 {
 	if (!ks) return -1;
 
-	if ((cursor_t) -1 == cursor)
+	if ((elektraCursor) -1 == cursor)
 	{
 		ksRewind (ks);
 		return 0;
@@ -1696,16 +1627,16 @@ static Key * elektraLookupBySpecLinks (KeySet * ks, Key * specKey, char * buffer
 	{
 		elektraWriteArrayNumber (&buffer[prefixSize], i);
 		m = keyGetMeta (specKey, buffer);
-		if (!m) break;
+		if (!m || keyGetValueSize (m) == 1) break;
 		// optimization: lazy instanziation of k
 		if (!k)
 		{
-			k = keyNew (keyString (m), KEY_CASCADING_NAME, KEY_END);
+			k = keyNew (keyString (m), KEY_END);
 			keySetBinary (k, keyValue (specKey), keyGetValueSize (specKey));
 			elektraCopyCallbackMeta (k, specKey);
 		}
 		else
-			elektraKeySetName (k, keyString (m), KEY_CASCADING_NAME);
+			keySetName (k, keyString (m));
 		ret = ksLookup (ks, k, KDB_O_NODEFAULT);
 		if (ret) break;
 		++i;
@@ -1731,18 +1662,22 @@ static Key * elektraLookupBySpecDefault (KeySet * ks, Key * specKey)
 	Key * ret = 0;
 	const Key * m = 0;
 
-	ret = ksLookup (ks, specKey, KDB_O_NOCASCADING);
+	keySetNamespace (specKey, KEY_NS_DEFAULT);
+	ret = ksLookup (ks, specKey, 0);
+
 	if (ret) return ret; // return previous added default key
 
 	m = keyGetMeta (specKey, "default");
 	if (!m) return ret;
-	ret = keyNew (keyName (specKey), KEY_CASCADING_NAME, KEY_VALUE, keyString (m), KEY_END);
+	ret = keyNew (keyName (specKey), KEY_VALUE, keyString (m), KEY_END);
 	ksAppendKey (ks, ret);
 
+	keySetNamespace (specKey, KEY_NS_CASCADING);
+
 	return ret;
 }
 
-static Key * elektraLookupByCascading (KeySet * ks, Key * key, option_t options);
+static Key * elektraLookupByCascading (KeySet * ks, Key * key, elektraLookupFlags options);
 
 /**
  * @internal
@@ -1766,24 +1701,12 @@ static Key * elektraLookupBySpecNamespaces (KeySet * ks, Key * specKey, char * b
 	// (obviously w/o spec)
 	if (!m) return elektraLookupByCascading (ks, specKey, KDB_O_NOSPEC | KDB_O_NODEFAULT);
 
-	// store old name of specKey
-	char * name = specKey->key;
-	size_t size = specKey->keySize;
-	size_t usize = specKey->keyUSize;
-	size_t nameLength = strlen (name);
-	size_t maxSize = nameLength + ELEKTRA_MAX_NAMESPACE_SIZE;
-	char newname[maxSize * 2]; // buffer for all new names (namespace + cascading key name)
-
 	do
 	{
 		// lookup with given namespace
-		size_t namespaceSize = keyGetValueSize (m);
-		char * startOfName = newname + ELEKTRA_MAX_NAMESPACE_SIZE - namespaceSize;
-		strncpy (startOfName, keyString (m), namespaceSize);
-		strcpy (newname + ELEKTRA_MAX_NAMESPACE_SIZE - 1, name); // name starts with /
-		specKey->key = startOfName;
-		specKey->keySize = nameLength + namespaceSize;
-		elektraFinalizeName (specKey);
+		elektraNamespace ns = elektraReadNamespace (keyString (m), keyGetValueSize (m) - 1);
+		if (ns == KEY_NS_NONE) break;
+		keySetNamespace (specKey, ns);
 		ret = ksLookup (ks, specKey, 0);
 		if (ret) break;
 		++i; // start with 1 (#0 was already in buffer)
@@ -1793,9 +1716,7 @@ static Key * elektraLookupBySpecNamespaces (KeySet * ks, Key * specKey, char * b
 	} while (m);
 
 	// restore old cascading name
-	specKey->key = name;
-	specKey->keySize = size;
-	specKey->keyUSize = usize;
+	keySetNamespace (specKey, KEY_NS_CASCADING);
 	return ret;
 }
 
@@ -1804,17 +1725,12 @@ static Key * elektraLookupBySpecNamespaces (KeySet * ks, Key * specKey, char * b
  * @internal
  * @brief Helper for ksLookup
  */
-static Key * elektraLookupBySpec (KeySet * ks, Key * specKey, option_t options)
+static Key * elektraLookupBySpec (KeySet * ks, Key * specKey, elektraLookupFlags options)
 {
 	Key * ret = 0;
+	elektraNamespace oldNS = keyGetNamespace (specKey);
 	// strip away beginning of specKey
-	char * name = specKey->key;
-	// stays same if already cascading and
-	// root must not be cascaded, so the usage of strchr is safe.
-	specKey->key = strchr (name, '/');
-	size_t size = specKey->keySize;
-	specKey->keySize = size - (specKey->key - name);
-	elektraFinalizeName (specKey);
+	keySetNamespace (specKey, KEY_NS_CASCADING);
 
 	// lookup by override
 	char buffer[ELEKTRA_MAX_PREFIX_SIZE + ELEKTRA_MAX_ARRAY_SIZE] = "override/";
@@ -1837,9 +1753,7 @@ static Key * elektraLookupBySpec (KeySet * ks, Key * specKey, option_t options)
 	}
 
 finished:
-	specKey->key = name;
-	specKey->keySize = size;
-	elektraFinalizeName (specKey);
+	keySetNamespace (specKey, oldNS);
 
 	return ret;
 }
@@ -1848,34 +1762,24 @@ finished:
  * @internal
  * @brief Helper for ksLookup
  */
-static Key * elektraLookupByCascading (KeySet * ks, Key * key, option_t options)
+static Key * elektraLookupByCascading (KeySet * ks, Key * key, elektraLookupFlags options)
 {
-	char * name = key->key;
-	size_t size = key->keySize;
-	size_t usize = key->keyUSize;
-	size_t length = strlen (name) + ELEKTRA_MAX_NAMESPACE_SIZE;
-	char newname[length * 2];
+	elektraNamespace oldNS = keyGetNamespace (key);
 	Key * found = 0;
 	Key * specKey = 0;
 
 	if (!(options & KDB_O_NOSPEC))
 	{
-		strncpy (newname + 2, "spec", 5);
-		strcpy (newname + 6, name);
-		key->key = newname + 2;
-		key->keySize = length - 2;
-		elektraFinalizeName (key);
+		keySetNamespace (key, KEY_NS_SPEC);
 		specKey = ksLookup (ks, key, (options & ~KDB_O_DEL) | KDB_O_CALLBACK);
 	}
 
 	if (specKey)
 	{
 		// restore old name
-		key->key = name;
-		key->keySize = size;
-		key->keyUSize = usize;
+		keySetNamespace (key, oldNS);
 
-		if (strncmp (keyName (specKey), "spec/", 5))
+		if (strncmp (keyName (specKey), "spec:/", 5))
 		{ // the search was modified in a way that not a spec Key was returned
 			return specKey;
 		}
@@ -1891,47 +1795,35 @@ static Key * elektraLookupByCascading (KeySet * ks, Key * key, option_t options)
 	}
 
 	// default cascading:
-	strncpy (newname + 2, "proc", 5);
-	strcpy (newname + 6, name);
-	key->key = newname + 2;
-	key->keySize = length - 2;
-	elektraFinalizeName (key);
+	keySetNamespace (key, KEY_NS_PROC);
 	found = ksLookup (ks, key, options & ~KDB_O_DEL);
 
 	if (!found)
 	{
-		strncpy (newname + 3, "dir", 4);
-		strcpy (newname + 6, name);
-		key->key = newname + 3;
-		key->keySize = length - 3;
-		elektraFinalizeName (key);
+		keySetNamespace (key, KEY_NS_DIR);
 		found = ksLookup (ks, key, options & ~KDB_O_DEL);
 	}
 
 	if (!found)
 	{
-		strncpy (newname + 2, "user", 5);
-		strcpy (newname + 6, name);
-		key->key = newname + 2;
-		key->keySize = length - 2;
-		elektraFinalizeName (key);
+		keySetNamespace (key, KEY_NS_USER);
 		found = ksLookup (ks, key, options & ~KDB_O_DEL);
 	}
 
 	if (!found)
 	{
-		strncpy (newname, "system", 7);
-		strcpy (newname + 6, name);
-		key->key = newname;
-		key->keySize = length;
-		elektraFinalizeName (key);
+		keySetNamespace (key, KEY_NS_SYSTEM);
+		found = ksLookup (ks, key, options & ~KDB_O_DEL);
+	}
+
+	if (!found)
+	{
+		keySetNamespace (key, KEY_NS_DEFAULT);
 		found = ksLookup (ks, key, options & ~KDB_O_DEL);
 	}
 
 	// restore old cascading name
-	key->key = name;
-	key->keySize = size;
-	key->keyUSize = usize;
+	keySetNamespace (key, KEY_NS_CASCADING);
 
 	if (!found && !(options & KDB_O_NODEFAULT))
 	{
@@ -1942,9 +1834,9 @@ static Key * elektraLookupByCascading (KeySet * ks, Key * key, option_t options)
 	return found;
 }
 
-static Key * elektraLookupBinarySearch (KeySet * ks, Key const * key, option_t options)
+static Key * elektraLookupBinarySearch (KeySet * ks, Key const * key, elektraLookupFlags options)
 {
-	cursor_t cursor = 0;
+	elektraCursor cursor = 0;
 	cursor = ksGetCursor (ks);
 	Key ** found;
 	size_t jump = 0;
@@ -2070,10 +1962,10 @@ static int elektraLookupBuildOpmphm (KeySet * ks)
  * @return NULL when key not found
  *
  */
-static Key * elektraLookupOpmphmSearch (KeySet * ks, Key const * key, option_t options)
+static Key * elektraLookupOpmphmSearch (KeySet * ks, Key const * key, elektraLookupFlags options)
 {
 	ELEKTRA_ASSERT (opmphmIsBuild (ks->opmphm), "OPMPHM not build");
-	cursor_t cursor = 0;
+	elektraCursor cursor = 0;
 	cursor = ksGetCursor (ks);
 	size_t index = opmphmLookup (ks->opmphm, ks->size, keyName (key));
 	if (index >= ks->size)
@@ -2110,10 +2002,10 @@ static Key * elektraLookupOpmphmSearch (KeySet * ks, Key const * key, option_t o
  *
  * @return the found key
  */
-static Key * elektraLookupSearch (KeySet * ks, Key * key, option_t options)
+static Key * elektraLookupSearch (KeySet * ks, Key * key, elektraLookupFlags options)
 {
 	if (!ks->size) return 0;
-	typedef Key * (*callback_t) (KeySet * ks, Key * key, Key * found, option_t options);
+	typedef Key * (*callback_t) (KeySet * ks, Key * key, Key * found, elektraLookupFlags options);
 	union
 	{
 		callback_t f;
@@ -2225,7 +2117,7 @@ static Key * elektraLookupSearch (KeySet * ks, Key * key, option_t options)
 	return ret;
 }
 
-static Key * elektraLookupCreateKey (KeySet * ks, Key * key, ELEKTRA_UNUSED option_t options)
+static Key * elektraLookupCreateKey (KeySet * ks, Key * key, ELEKTRA_UNUSED elektraLookupFlags options)
 {
 	Key * ret = keyDup (key);
 	ksAppendKey (ks, ret);
@@ -2267,8 +2159,8 @@ static Key * elektraLookupCreateKey (KeySet * ks, Key * key, ELEKTRA_UNUSED opti
  * returned.
  *
  * Cascading lookups will by default search in
- * all namespaces (proc/, dir/, user/ and system/), but will also correctly consider
- * the specification (=metadata) in spec/:
+ * all namespaces (proc:/, dir:/, user:/ and system:/), but will also correctly consider
+ * the specification (=metadata) in spec:/:
  *
  * - @p override/# will make sure that another key is considered before
  * - @p namespace/# will change the number and/or order in which the
@@ -2316,13 +2208,13 @@ static Key * elektraLookupCreateKey (KeySet * ks, Key * key, ELEKTRA_UNUSED opti
  *
  * @param ks where to look for
  * @param key the key object you are looking for
- * @param options of type ::option_t with some @p KDB_O_* option bits as explained above
+ * @param options of type ::elektraLookupFlags with some @p KDB_O_* option bits as explained above
  * @return pointer to the Key found, 0 otherwise
  * @retval 0 on NULL pointers
  * @see ksLookupByName() to search by a name given by a string
  * @see ksCurrent(), ksRewind(), ksNext() for iterating over a keyset
  */
-Key * ksLookup (KeySet * ks, Key * key, option_t options)
+Key * ksLookup (KeySet * ks, Key * key, elektraLookupFlags options)
 {
 	if (!ks) return 0;
 	if (!key) return 0;
@@ -2384,7 +2276,7 @@ Key * ksLookup (KeySet * ks, Key * key, option_t options)
  * @see ksLookup() to search with a given key
  * @see ksCurrent(), ksRewind(), ksNext()
  */
-Key * ksLookupByName (KeySet * ks, const char * name, option_t options)
+Key * ksLookupByName (KeySet * ks, const char * name, elektraLookupFlags options)
 {
 	Key * found = 0;
 
@@ -2396,10 +2288,11 @@ Key * ksLookupByName (KeySet * ks, const char * name, option_t options)
 	struct _Key key;
 	key.meta = NULL;
 	keyInit (&key);
-	elektraKeySetName (&key, name, KEY_META_NAME | KEY_CASCADING_NAME);
+	keySetName (&key, name);
 
 	found = ksLookup (ks, &key, options);
 	elektraFree (key.key);
+	elektraFree (key.ukey);
 	ksDel (key.meta); // sometimes owner is set
 	return found;
 }
@@ -2457,7 +2350,6 @@ int ksResize (KeySet * ks, size_t alloc)
 		clear_bit (ks->flags, (keyflag_t) KS_FLAG_MMAP_ARRAY);
 		if (!ks->array)
 		{
-			/*errno = KDB_ERR_NOMEM;*/
 			return -1;
 		}
 	}
@@ -2469,7 +2361,6 @@ int ksResize (KeySet * ks, size_t alloc)
 		Key ** new = elektraMalloc (sizeof (struct _Key *) * ks->alloc);
 		if (!new)
 		{
-			/*errno = KDB_ERR_NOMEM;*/
 			return -1;
 		}
 		elektraMemcpy (new, ks->array, ks->size + 1); // copy including ending NULL
@@ -2481,7 +2372,6 @@ int ksResize (KeySet * ks, size_t alloc)
 	{
 		elektraFree (ks->array);
 		ks->array = 0;
-		/*errno = KDB_ERR_NOMEM;*/
 		return -1;
 	}
 
