@@ -75,7 +75,7 @@ int elektraAugeasGenConf (KeySet * ks, Key * errorKey ELEKTRA_UNUSED)
 			if (l > 4)
 			{
 				p[l - 4] = '\0';
-				Key * k = keyNew ("system/", KEY_END);
+				Key * k = keyNew ("system:/", KEY_END);
 				keyAddBaseName (k, p);
 				ksAppendKey (ks, keyDup (k));
 
@@ -166,22 +166,40 @@ static const char * getAugeasError (augeas * augeasHandle, const char * lensPath
 static Key * createKeyFromPath (Key * parentKey, const char * treePath)
 {
 	Key * key = keyDup (parentKey);
-	const char * baseName = (treePath + strlen (AUGEAS_TREE_ROOT) + 1);
+	char * baseName = elektraStrDup (treePath + strlen (AUGEAS_TREE_ROOT) + 1);
+	char * lastSlash = strrchr (baseName, '/');
+	const char * lastPart = lastSlash != NULL ? lastSlash + 1 : baseName;
 
-	size_t baseSize = (size_t) keyGetNameSize (key);
-	size_t keyNameSize = strlen (baseName) + baseSize + 1;
-	char * newName = elektraMalloc (keyNameSize);
-
-	if (!newName) return 0;
-
-	strcpy (newName, keyName (key));
-	newName[baseSize - 1] = KDB_PATH_SEPARATOR;
-	newName[baseSize] = 0;
-	strcat (newName, baseName);
-
-	keySetName (key, newName);
-	elektraFree (newName);
+	if (strcmp (lastPart, "#comment") == 0)
+	{
+		if (lastSlash != NULL)
+		{
+			*lastSlash = '\0';
+			if (keyAddName (key, baseName) < 0)
+			{
+				keyDel (key);
+				elektraFree (baseName);
+				return NULL;
+			}
+		}
 
+		if (keyAddBaseName (key, lastPart) < 0)
+		{
+			keyDel (key);
+			elektraFree (baseName);
+			return NULL;
+		}
+	}
+	else
+	{
+		if (keyAddName (key, baseName) < 0)
+		{
+			keyDel (key);
+			elektraFree (baseName);
+			return NULL;
+		}
+	}
+	elektraFree (baseName);
 	return key;
 }
 
@@ -202,6 +220,8 @@ static int convertToKey (augeas * handle, const char * treePath, void * data)
 
 	Key * key = createKeyFromPath (conversionData->parentKey, treePath);
 
+	if (key == NULL) return -1;
+
 	/* fill key values */
 	keySetString (key, value);
 	conversionData->currentOrder++;
@@ -389,6 +409,12 @@ static int saveTree (augeas * augeasHandle, KeySet * ks, const char * lensPath,
 
 		if (ret < 0) goto memoryerror;
 
+		if (strcmp (keyBaseName (key), "#comment") == 0)
+		{
+			size_t offset = strlen (nodeName) - sizeof ("#comment") + 1;
+			strcpy (nodeName + offset, "#comment");
+		}
+
 		aug_set (augeasHandle, nodeName, keyString (key));
 		elektraFree (nodeName);
 	}
@@ -468,7 +494,7 @@ int elektraAugeasGet (Plugin * handle, KeySet * returned, Key * parentKey)
 	int errnosave = errno;
 	int ret = 0;
 
-	if (!strcmp (keyName (parentKey), "system/elektra/modules/augeas"))
+	if (!strcmp (keyName (parentKey), "system:/elektra/modules/augeas"))
 	{
 		KeySet * info =
 #include "contract.h"
@@ -482,7 +508,11 @@ int elektraAugeasGet (Plugin * handle, KeySet * returned, Key * parentKey)
 
 	/* retrieve the lens to use */
 	const char * lensPath = getLensPath (handle);
-	if (!lensPath) ELEKTRA_SET_INSTALLATION_ERRORF (parentKey, "No Augeas lens was configured: %s", keyName (parentKey));
+	if (!lensPath)
+	{
+		ELEKTRA_SET_INSTALLATION_ERRORF (parentKey, "No Augeas lens was configured: %s", keyName (parentKey));
+		return ELEKTRA_PLUGIN_STATUS_ERROR;
+	}
 
 	FILE * fh = fopen (keyString (parentKey), "r");
 
@@ -490,7 +520,7 @@ int elektraAugeasGet (Plugin * handle, KeySet * returned, Key * parentKey)
 	{
 		ELEKTRA_SET_ERROR_GET (parentKey);
 		errno = errnosave;
-		return -1;
+		return ELEKTRA_PLUGIN_STATUS_ERROR;
 	}
 
 	/* load its contents into a string */
@@ -500,6 +530,7 @@ int elektraAugeasGet (Plugin * handle, KeySet * returned, Key * parentKey)
 	{
 		fclose (fh);
 		ELEKTRA_SET_RESOURCE_ERRORF (parentKey, "Error while reading file. Reason: %s", strerror (errno));
+		return ELEKTRA_PLUGIN_STATUS_ERROR;
 	}
 
 	/* convert the string into an augeas tree */
@@ -511,7 +542,7 @@ int elektraAugeasGet (Plugin * handle, KeySet * returned, Key * parentKey)
 		fclose (fh);
 		ELEKTRA_SET_INSTALLATION_ERROR (parentKey, getAugeasError (augeasHandle, lensPath));
 		errno = errnosave;
-		return -1;
+		return ELEKTRA_PLUGIN_STATUS_ERROR;
 	}
 
 	/* convert the augeas tree to an Elektra KeySet */
@@ -527,14 +558,16 @@ int elektraAugeasGet (Plugin * handle, KeySet * returned, Key * parentKey)
 	{
 		fclose (fh);
 		ELEKTRA_SET_OUT_OF_MEMORY_ERROR (parentKey);
+		return ELEKTRA_PLUGIN_STATUS_ERROR;
 	}
 
 	conversionData->currentOrder = 0;
-	conversionData->parentKey = key;
+	conversionData->parentKey = keyDup (key);
 	conversionData->ks = append;
 
 	ret = foreachAugeasNode (augeasHandle, AUGEAS_TREE_ROOT, &convertToKey, conversionData);
 
+	keyDel (conversionData->parentKey);
 	elektraFree (conversionData);
 
 	if (ret < 0)
@@ -543,7 +576,7 @@ int elektraAugeasGet (Plugin * handle, KeySet * returned, Key * parentKey)
 		ksDel (append);
 		ELEKTRA_SET_INSTALLATION_ERROR (parentKey, getAugeasError (augeasHandle, lensPath));
 		errno = errnosave;
-		return -1;
+		return ELEKTRA_PLUGIN_STATUS_ERROR;
 	}
 
 	fclose (fh);
@@ -564,6 +597,7 @@ int elektraAugeasSet (Plugin * handle, KeySet * returned, Key * parentKey)
 	if (!lensPath)
 	{
 		ELEKTRA_SET_INSTALLATION_ERRORF (parentKey, "No Augeas lens was configured: %s", keyName (parentKey));
+		return ELEKTRA_PLUGIN_STATUS_ERROR;
 	}
 
 	FILE * fh = fopen (keyValue (parentKey), "w+");
@@ -572,7 +606,7 @@ int elektraAugeasSet (Plugin * handle, KeySet * returned, Key * parentKey)
 	{
 		ELEKTRA_SET_ERROR_SET (parentKey);
 		errno = errnosave;
-		return -1;
+		return ELEKTRA_PLUGIN_STATUS_ERROR;
 	}
 
 	int ret = 0;
@@ -597,7 +631,7 @@ int elektraAugeasSet (Plugin * handle, KeySet * returned, Key * parentKey)
 			fclose (fh);
 			ELEKTRA_SET_INSTALLATION_ERROR (parentKey, getAugeasError (augeasHandle, lensPath));
 			errno = errnosave;
-			return -1;
+			return ELEKTRA_PLUGIN_STATUS_ERROR;
 		}
 	}
 
@@ -607,14 +641,18 @@ int elektraAugeasSet (Plugin * handle, KeySet * returned, Key * parentKey)
 	{
 		fclose (fh);
 		errno = errnosave;
-		return -1;
+		return ELEKTRA_PLUGIN_STATUS_ERROR;
 	}
 
 	/* write the Augeas tree to the file */
 	ret = saveFile (augeasHandle, fh);
 	fclose (fh);
 
-	if (ret < 0) ELEKTRA_SET_RESOURCE_ERRORF (parentKey, "Could not open file for writing. Reason: %s", strerror (errno));
+	if (ret < 0)
+	{
+		ELEKTRA_SET_RESOURCE_ERRORF (parentKey, "Could not open file for writing. Reason: %s", strerror (errno));
+		return ELEKTRA_PLUGIN_STATUS_ERROR;
+	}
 
 	errno = errnosave;
 	return 1;
