@@ -14,7 +14,6 @@
 #endif
 
 #include <kdbextension.h>
-#include <kdbproposal.h>
 
 static int keyCmpOrderWrapper (const void * a, const void * b)
 {
@@ -59,9 +58,8 @@ static const char * getMetaValue (Key * key, const char * metaName)
 
 static void writeLineComments (Key * key, FILE * fp)
 {
-	// TODO: this is really inefficient
-	KeySet * metaKeys = elektraKeyGetMetaKeySet (key);
-	Key * commentParent = keyNew ("comment", KEY_META_NAME, KEY_END);
+	KeySet * metaKeys = keyMeta (key);
+	Key * commentParent = keyNew ("meta:/comment", KEY_END);
 	KeySet * comments = elektraArrayGet (commentParent, metaKeys);
 	keyDel (commentParent);
 
@@ -69,7 +67,7 @@ static void writeLineComments (Key * key, FILE * fp)
 	Key * current;
 	while ((current = ksNext (comments)))
 	{
-		if (strcmp (keyName (current), "comment/#0"))
+		if (strcmp (keyName (current), "meta:/comment/#0") != 0)
 		{
 			Key * spaceKey = keyDup (current);
 			keyAddBaseName (spaceKey, "space");
@@ -85,7 +83,6 @@ static void writeLineComments (Key * key, FILE * fp)
 		}
 	}
 
-	ksDel (metaKeys);
 	ksDel (comments);
 }
 
@@ -109,7 +106,7 @@ static void writeHostsEntry (Key * key, KeySet * returned, FILE * fp)
 	Key * alias;
 	while ((alias = ksNext (returned)) != 0)
 	{
-		if (keyRel (key, alias) < 1) break;
+		if (keyIsBelow (key, alias) != 1) break;
 
 		fprintf (fp, " %s", (char *) keyBaseName (alias));
 	}
@@ -157,7 +154,7 @@ int elektraHostsSet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned, Key * pa
 		Key * key = keyArray[i];
 
 		/* only process canonical name keys */
-		if (!keyIsDirectBelow (ipv4Base, key) && !keyIsDirectBelow (ipv6Base, key)) continue;
+		if (!keyIsDirectlyBelow (ipv4Base, key) && !keyIsDirectlyBelow (ipv6Base, key)) continue;
 
 		writeLineComments (key, fp);
 		writeHostsEntry (key, returned, fp);
