@@ -325,7 +325,7 @@ static int handleErrors (Key * key, Key * parentKey, KeySet * ks, Key * specKey,
 	Key * parentLookup = keyDup (key);
 	keySetBaseName (parentLookup, NULL);
 
-	cursor_t cursor = ksGetCursor (ks);
+	elektraCursor cursor = ksGetCursor (ks);
 	Key * parent = ksLookup (ks, parentLookup, KDB_O_NONE);
 	ksSetCursor (ks, cursor);
 
@@ -358,7 +358,7 @@ static int processAllConflicts (Key * specKey, KeySet * ks, Key * parentKey, con
 
 /**
  * Checks whether the given key is an array spec,
- * i.e. it has a keyname part that is "#".
+ * i.e. it has at least one keyname part that is "#".
  *
  * @param key a spec key
  *
@@ -386,6 +386,36 @@ static bool isArraySpec (const Key * key)
 	return false;
 }
 
+/**
+ * Checks whether the given key is an instantiated array spec,
+ * i.e. its last keyname part is "#" and no other keyname part is "#".
+ *
+ * @param key a spec key
+ *
+ * @retval #true  if @p key is an array spec
+ * @retval #false otherwise
+ */
+static bool isInstantiatedArraySpec (const Key * key)
+{
+	size_t usize = keyGetUnescapedNameSize (key);
+	const char * cur = keyUnescapedName (key);
+	const char * end = cur + usize;
+
+	while (cur < end)
+	{
+		size_t len = strlen (cur);
+
+		if (len == 1 && cur[0] == '#')
+		{
+			return cur + len + 1 >= end;
+		}
+
+		cur += len + 1;
+	}
+
+	return false;
+}
+
 static bool validateArraySize (Key * arrayParent, Key * spec)
 {
 	const Key * arrayActualKey = keyGetMeta (arrayParent, "array");
@@ -430,20 +460,12 @@ static void validateEmptyArray (KeySet * ks, Key * arraySpecParent, Key * parent
 	ksRewind (subKeys);
 	while ((cur = ksNext (subKeys)) != NULL)
 	{
-		if (keyIsBelow (parentLookup, cur) == 0)
+		if (keyIsBelow (parentLookup, cur) == 0 || keyGetNamespace (cur) == KEY_NS_SPEC)
 		{
 			continue;
 		}
 
-		const char * checkStr = keyUnescapedName (cur);
-		ssize_t len = strlen (checkStr);
-
-		if (keyGetUnescapedNameSize (cur) - len == parentLen)
-		{
-			continue;
-		}
-
-		checkStr += len;
+		const char * checkStr = strchr (keyName (cur), ':');
 		checkStr += parentLen;
 
 		if (elektraArrayValidateBaseNameString (checkStr) < 0)
@@ -502,20 +524,13 @@ static void validateArrayMembers (KeySet * ks, Key * arraySpec)
 	ksRewind (subKeys);
 	while ((cur = ksNext (subKeys)) != NULL)
 	{
-		if (keyIsBelow (parentLookup, cur) == 0)
+		if (keyIsBelow (parentLookup, cur) == 0 || keyGetNamespace (cur) == KEY_NS_SPEC ||
+		    keyGetNamespace (cur) == KEY_NS_CASCADING)
 		{
 			continue;
 		}
 
-		const char * checkStr = keyUnescapedName (cur);
-		ssize_t len = strlen (checkStr);
-
-		if (keyGetUnescapedNameSize (cur) - len == parentLen)
-		{
-			continue;
-		}
-
-		checkStr += len;
+		const char * checkStr = strchr (keyName (cur), ':');
 		checkStr += parentLen;
 
 		if (elektraArrayValidateBaseNameString (checkStr) < 0)
@@ -534,16 +549,16 @@ static void validateArrayMembers (KeySet * ks, Key * arraySpec)
 // instantiates all array spec parts in an array spec key (e.g. abc/#/a/d/#/e)
 static KeySet * instantiateArraySpec (KeySet * ks, Key * arraySpec, Key * parentKey, OnConflict onConflict)
 {
-	cursor_t cursor = ksGetCursor (ks);
+	elektraCursor cursor = ksGetCursor (ks);
 	size_t usize = keyGetUnescapedNameSize (arraySpec);
 	const char * cur = keyUnescapedName (arraySpec);
 	const char * end = cur + usize;
 
-	cur += strlen (cur) + 1; // skip "spec"
+	cur += strlen (cur) + 1; // skip "spec:"
 
-	KeySet * newKeys = ksNew (1, keyNew ("spec", KEY_END), KS_END);
+	KeySet * newKeys = ksNew (1, keyNew ("spec:/", KEY_END), KS_END);
 	KeySet * parents = ksNew (0, KS_END);
-	Key * specCur = keyNew ("spec", KEY_END);
+	Key * specCur = keyNew ("spec:/", KEY_END);
 
 	while (cur < end)
 	{
@@ -720,33 +735,43 @@ static void validateWildcardSubs (KeySet * ks, Key * key)
  */
 static void copyMeta (Key * dest, Key * src)
 {
-	keyRewindMeta (src);
-	const Key * meta;
-	while ((meta = keyNextMeta (src)) != NULL)
+	KeySet * metaKS = ksDup (keyMeta (src));
+
+	Key * cutpoint = keyNew ("meta:/internal", KEY_END);
+	ksDel (ksCut (metaKS, cutpoint)); // don't care for internal stuff
+
+	keySetName (cutpoint, "meta:/conflict");
+	ksDel (ksCut (metaKS, cutpoint)); // don't care for conflict stuff
+
+	keyDel (cutpoint);
+
+	// TODO: could be optimized by iterating both meta key sets simultaneously
+	for (elektraCursor cursor = 0; cursor < ksGetSize (metaKS); ++cursor)
 	{
+		Key * meta = ksAtCursor (metaKS, cursor);
 		const char * name = keyName (meta);
-		if (strncmp (name, "internal/", 9) != 0 && strncmp (name, "conflict/", 9) != 0)
+
+		const Key * oldMeta = keyGetMeta (dest, name);
+		if (oldMeta != NULL)
 		{
-			const Key * oldMeta = keyGetMeta (dest, name);
-			if (oldMeta != NULL)
+			// don't overwrite metadata
+			// array metadata is not a conflict
+			if (strcmp (name, "meta:/array") != 0 && strcmp (keyString (oldMeta), keyString (meta)) != 0)
 			{
-				// don't overwrite metadata
-				// array metadata is not a conflict
-				if (strcmp (name, "array") != 0 && strcmp (keyString (oldMeta), keyString (meta)) != 0)
-				{
-					char * conflictName = elektraFormat ("conflict/%s", name);
-					keySetMeta (dest, conflictName, keyString (oldMeta));
-					elektraFree (conflictName);
-					addConflict (dest, CONFLICT_COLLISION);
-					elektraMetaArrayAdd (dest, "conflict/collision", name);
-				}
-			}
-			else
-			{
-				keyCopyMeta (dest, src, name);
+				char * conflictName = elektraFormat ("conflict/%s", name);
+				keySetMeta (dest, conflictName, keyString (oldMeta));
+				elektraFree (conflictName);
+				addConflict (dest, CONFLICT_COLLISION);
+				elektraMetaArrayAdd (dest, "conflict/collision", name);
 			}
 		}
+		else
+		{
+			keyCopyMeta (dest, src, name);
+		}
 	}
+
+	ksDel (metaKS);
 }
 
 /**
@@ -766,22 +791,23 @@ static int processSpecKey (Key * specKey, Key * parentKey, KeySet * ks, const Co
 	bool require = keyGetMeta (specKey, "require") != NULL;
 	bool wildcardSpec = isWildcardSpec (specKey);
 
-	if (isArraySpec (specKey))
+	if (isInstantiatedArraySpec (specKey))
 	{
+		// check instantiated arrays
 		validateArrayMembers (ks, specKey);
 		return 0;
 	}
 
-	int found = 0;
-	Key * cur;
-
-	ksRewind (ks);
-	ksNext (ks); // set cursor to first
-
-	// externalize cursor to avoid having to reset after ksLookups
-	cursor_t cursor = ksGetCursor (ks);
-	for (; (cur = ksAtCursor (ks, cursor)) != NULL; ++cursor)
+	if (isArraySpec (specKey))
 	{
+		// ignore other arrays
+		return 0;
+	}
+
+	int found = 0;
+	for (elektraCursor cursor = 0; cursor < ksGetSize (ks); ++cursor)
+	{
+		Key * cur = ksAtCursor (ks, cursor);
 		if (!specMatches (specKey, cur))
 		{
 			continue;
@@ -822,14 +848,15 @@ static int processSpecKey (Key * specKey, Key * parentKey, KeySet * ks, const Co
 		{
 			if (keyGetMeta (specKey, "assign/condition") != NULL)
 			{
-				Key * newKey = keyNew (strchr (keyName (specKey), '/'), KEY_CASCADING_NAME, KEY_END);
+				Key * newKey = keyNew ("default:/", KEY_END);
+				keyAddName (newKey, strchr (keyName (specKey), '/'));
 				copyMeta (newKey, specKey);
 				ksAppendKey (ks, newKey);
 			}
 			else if (keyGetMeta (specKey, "default") != NULL)
 			{
-				Key * newKey = keyNew (strchr (keyName (specKey), '/'), KEY_CASCADING_NAME, KEY_VALUE,
-						       keyString (keyGetMeta (specKey, "default")), KEY_END);
+				Key * newKey = keyNew ("default:/", KEY_VALUE, keyString (keyGetMeta (specKey, "default")), KEY_END);
+				keyAddName (newKey, strchr (keyName (specKey), '/'));
 				copyMeta (newKey, specKey);
 				ksAppendKey (ks, newKey);
 			}
@@ -837,7 +864,8 @@ static int processSpecKey (Key * specKey, Key * parentKey, KeySet * ks, const Co
 
 		if (keyGetMeta (specKey, "array") != NULL)
 		{
-			Key * newKey = keyNew (strchr (keyName (specKey), '/'), KEY_CASCADING_NAME, KEY_END);
+			Key * newKey = keyNew ("default:/", KEY_END);
+			keyAddName (newKey, strchr (keyName (specKey), '/'));
 			copyMeta (newKey, specKey);
 			if (!isKdbGet)
 			{
@@ -852,15 +880,15 @@ static int processSpecKey (Key * specKey, Key * parentKey, KeySet * ks, const Co
 
 int elektraSpecGet (Plugin * handle, KeySet * returned, Key * parentKey)
 {
-	if (!elektraStrCmp (keyName (parentKey), "system/elektra/modules/spec"))
+	if (!elektraStrCmp (keyName (parentKey), "system:/elektra/modules/spec"))
 	{
 		KeySet * contract =
-			ksNew (30, keyNew ("system/elektra/modules/spec", KEY_VALUE, "spec plugin waits for your orders", KEY_END),
-			       keyNew ("system/elektra/modules/spec/exports", KEY_END),
-			       keyNew ("system/elektra/modules/spec/exports/get", KEY_FUNC, elektraSpecGet, KEY_END),
-			       keyNew ("system/elektra/modules/spec/exports/set", KEY_FUNC, elektraSpecSet, KEY_END),
+			ksNew (30, keyNew ("system:/elektra/modules/spec", KEY_VALUE, "spec plugin waits for your orders", KEY_END),
+			       keyNew ("system:/elektra/modules/spec/exports", KEY_END),
+			       keyNew ("system:/elektra/modules/spec/exports/get", KEY_FUNC, elektraSpecGet, KEY_END),
+			       keyNew ("system:/elektra/modules/spec/exports/set", KEY_FUNC, elektraSpecSet, KEY_END),
 #include ELEKTRA_README
-			       keyNew ("system/elektra/modules/spec/infos/version", KEY_VALUE, PLUGINVERSION, KEY_END), KS_END);
+			       keyNew ("system:/elektra/modules/spec/infos/version", KEY_VALUE, PLUGINVERSION, KEY_END), KS_END);
 		ksAppend (returned, contract);
 		ksDel (contract);
 
@@ -900,7 +928,7 @@ int elektraSpecGet (Plugin * handle, KeySet * returned, Key * parentKey)
 	}
 
 	// remove spec namespace from returned
-	Key * specParent = keyNew ("spec", KEY_END);
+	Key * specParent = keyNew ("spec:/", KEY_END);
 	ksDel (ksCut (returned, specParent));
 	keyDel (specParent);
 
@@ -971,7 +999,7 @@ int elektraSpecSet (Plugin * handle, KeySet * returned, Key * parentKey)
 	}
 
 	// remove spec namespace from returned
-	Key * specParent = keyNew ("spec", KEY_END);
+	Key * specParent = keyNew ("spec:/", KEY_END);
 	ksDel (ksCut (returned, specParent));
 	keyDel (specParent);
 
