@@ -8,7 +8,7 @@
 
 // -- Imports ------------------------------------------------------------------
 
-#include <antlr4-runtime.h>
+#include <antlr4-runtime/antlr4-runtime.h>
 
 namespace yanlr
 {
